@@ -31,7 +31,13 @@ bool __wrap_l_getrandom(void *buf, size_t len)
 						0x7f, 0xe2, 0x8d, 0x46, 0xb0,
 						0x73, 0xcd, 0xd3, 0x6a, 0x7b,
 						0xa6, 0xd3, 0xde, 0xbf, 0x38,
-						0x96, 0xb7, 0xc3 };
+						0x96, 0xb7, 0xc3, 0xd4, 0xc1,
+						0xcf, 0x46, 0xd4, 0x35, 0x66,
+						0x04, 0x56, 0xd5, 0x61, 0x55,
+						0x52, 0x20, 0xfa, 0x18, 0x97,
+						0x5a, 0x7c, 0x76, 0x35, 0xd3,
+						0x63, 0x3e };
+
 
 	if (use_real_getrandom)
 		return __real_l_getrandom(buf, len);
@@ -44,6 +50,11 @@ bool __wrap_l_getrandom(void *buf, size_t len)
 	return true;
 }
 
+static bool getrandom_precheck(const void *data)
+{
+	return l_getrandom_is_supported();
+}
+
 /*
  * Tests the most basic case. Generate two full public keys and use to create
  * two identical shared secrets.
@@ -408,9 +419,9 @@ static void test_vector_p521(const void *data)
 	l_ecc_scalar_free(b_shared);
 }
 
-#define add_basic_test(name, group) l_test_add_data_func(name, \
+#define add_basic_test(name, group) l_test_add_data_func_precheck(name, \
 					L_UINT_TO_PTR(group), \
-					test_basic, L_TEST_FLAG_ALLOW_FAILURE)
+					test_basic, getrandom_precheck, 0)
 
 int main(int argc, char *argv[])
 {
